@@ -51,7 +51,7 @@ def _get_data_from_rawfile(path_to_data, raw_data_id):
     loaded = pickle.load(open(path_to_data))
     raw_datasets = loaded['handwriting_datasets']
     for raw_dataset in raw_datasets:
-        if raw_dataset['formula_id'] == raw_data_id:
+        if raw_dataset['handwriting'].raw_data_id == raw_data_id:
             return raw_dataset['handwriting']
     return None
 
